<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) === strtr(__FILE__, '\\', '/') )  exit;

//*****************************************************************************/
// mainfile.phpɤ߹
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) {
	$root_path_dir = dirname( dirname(dirname(dirname(__FILE__))) );
	include_once( $root_path_dir .'/mainfile.php' );
}

//*****************************************************************************/
// ⥸塼ROOT_PATHURLꤹDuplicatableˤ뤿ˤϤʤ
//*****************************************************************************/
$mod_path = dirname( dirname(__FILE__) );
$mod_url = str_replace( XOOPS_ROOT_PATH, XOOPS_URL, strtr($mod_path, '\\', '/') );
$mod_name = basename(dirname(dirname(__FILE__)));

?>